
// this file was generated by codegen.py

// __AVR_LIBC_VERSION_STRING__ = "1.8.0"
// __AVR_LIBC_DATE_STRING__ = "20111228"
            

#ifdef __AVR_AT43USB320__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT43USB320__"
#endif

#ifdef __AVR_AT43USB355__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT43USB355__"
#endif

#ifdef __AVR_AT76C711__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT76C711__"
#endif

#ifdef __AVR_AT86RF401__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT86RF401__"
#endif

#ifdef __AVR_AT90C8534__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90C8534__"
#endif

#ifdef __AVR_AT90CAN128__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90CAN128__"
#endif

#ifdef __AVR_AT90CAN32__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90CAN32__"
#endif

#ifdef __AVR_AT90CAN64__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90CAN64__"
#endif

#ifdef __AVR_AT90PWM1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM1__"
#endif

#ifdef __AVR_AT90PWM216__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM216__"
#endif

#ifdef __AVR_AT90PWM2B__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM2B__"
#endif

#ifdef __AVR_AT90PWM2__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM2__"
#endif

#ifdef __AVR_AT90PWM316__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM316__"
#endif

#ifdef __AVR_AT90PWM3B__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM3B__"
#endif

#ifdef __AVR_AT90PWM3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM3__"
#endif

#ifdef __AVR_AT90PWM81__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90PWM81__"
#endif

#ifdef __AVR_AT90S1200__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S1200__"
#endif

#ifdef __AVR_AT90S2313__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S2313__"
#endif

#ifdef __AVR_AT90S2323__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S2323__"
#endif

#ifdef __AVR_AT90S2333__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S2333__"
#endif

#ifdef __AVR_AT90S2343__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S2343__"
#endif

#ifdef __AVR_AT90S4414__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S4414__"
#endif

#ifdef __AVR_AT90S4433__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S4433__"
#endif

#ifdef __AVR_AT90S4434__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S4434__"
#endif

#ifdef __AVR_AT90S8515__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S8515__"
#endif

#ifdef __AVR_AT90S8535__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90S8535__"
#endif

#ifdef __AVR_AT90SCR100__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90SCR100__"
#endif

#ifdef __AVR_AT90USB1286__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90USB1286__"
#endif

#ifdef __AVR_AT90USB1287__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90USB1287__"
#endif

#ifdef __AVR_AT90USB162__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90USB162__"
#endif

#ifdef __AVR_AT90USB646__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90USB646__"
#endif

#ifdef __AVR_AT90USB647__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90USB647__"
#endif

#ifdef __AVR_AT90USB82__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT90USB82__"
#endif

#ifdef __AVR_AT94K__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_AT94K__"
#endif

#ifdef __AVR_ATA6289__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATA6289__"
#endif

#ifdef __AVR_ATmega103__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega103__"
#endif

#ifdef __AVR_ATmega1280__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega1280__"
#endif

#ifdef __AVR_ATmega1281__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega1281__"
#endif

#ifdef __AVR_ATmega1284P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega1284P__"
#endif

#ifdef __AVR_ATmega128RFA1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega128RFA1__"
#endif

#ifdef __AVR_ATmega128__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega128__"
#endif

#ifdef __AVR_ATmega161__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega161__"
#endif

#ifdef __AVR_ATmega162__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega162__"
#endif

#ifdef __AVR_ATmega163__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega163__"
#endif

#ifdef __AVR_ATmega164A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega164A__"
#endif

#ifdef __AVR_ATmega164P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega164P__"
#endif

#ifdef __AVR_ATmega164__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega164__"
#endif

#ifdef __AVR_ATmega165A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega165A__"
#endif

#ifdef __AVR_ATmega165P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega165P__"
#endif

#ifdef __AVR_ATmega165__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega165__"
#endif

#ifdef __AVR_ATmega168A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega168A__"
#endif

#ifdef __AVR_ATmega168P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega168P__"
#endif

#ifdef __AVR_ATmega168__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega168__"
#endif

#ifdef __AVR_ATmega169A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega169A__"
#endif

#ifdef __AVR_ATmega169PA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega169PA__"
#endif

#ifdef __AVR_ATmega169P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega169P__"
#endif

#ifdef __AVR_ATmega169__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega169__"
#endif

#ifdef __AVR_ATmega16A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16A__"
#endif

#ifdef __AVR_ATmega16HVA2__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16HVA2__"
#endif

#ifdef __AVR_ATmega16HVA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16HVA__"
#endif

#ifdef __AVR_ATmega16HVBREVB__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16HVBREVB__"
#endif

#ifdef __AVR_ATmega16HVB__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16HVB__"
#endif

#ifdef __AVR_ATmega16M1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16M1__"
#endif

#ifdef __AVR_ATmega16U2__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16U2__"
#endif

#ifdef __AVR_ATmega16U4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16U4__"
#endif

#ifdef __AVR_ATmega16__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega16__"
#endif

#ifdef __AVR_ATmega2560__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega2560__"
#endif

#ifdef __AVR_ATmega2561__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega2561__"
#endif

#ifdef __AVR_ATmega323__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega323__"
#endif

#ifdef __AVR_ATmega324A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega324A__"
#endif

#ifdef __AVR_ATmega324PA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega324PA__"
#endif

#ifdef __AVR_ATmega324P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega324P__"
#endif

#ifdef __AVR_ATmega3250A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega3250A__"
#endif

#ifdef __AVR_ATmega3250P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega3250P__"
#endif

#ifdef __AVR_ATmega3250__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega3250__"
#endif

#ifdef __AVR_ATmega325A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega325A__"
#endif

#ifdef __AVR_ATmega325P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega325P__"
#endif

#ifdef __AVR_ATmega325__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega325__"
#endif

#ifdef __AVR_ATmega328P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega328P__"
#endif

#ifdef __AVR_ATmega328__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega328__"
#endif

#ifdef __AVR_ATmega3290A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega3290A__"
#endif

#ifdef __AVR_ATmega3290P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega3290P__"
#endif

#ifdef __AVR_ATmega3290__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega3290__"
#endif

#ifdef __AVR_ATmega329A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega329A__"
#endif

#ifdef __AVR_ATmega329PA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega329PA__"
#endif

#ifdef __AVR_ATmega329P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega329P__"
#endif

#ifdef __AVR_ATmega329__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega329__"
#endif

#ifdef __AVR_ATmega32C1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32C1__"
#endif

#ifdef __AVR_ATmega32HVBREVB__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32HVBREVB__"
#endif

#ifdef __AVR_ATmega32HVB__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32HVB__"
#endif

#ifdef __AVR_ATmega32M1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32M1__"
#endif

#ifdef __AVR_ATmega32U2__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32U2__"
#endif

#ifdef __AVR_ATmega32U4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32U4__"
#endif

#ifdef __AVR_ATmega32U6__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32U6__"
#endif

#ifdef __AVR_ATmega32__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega32__"
#endif

#ifdef __AVR_ATmega406__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega406__"
#endif

#ifdef __AVR_ATmega48A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega48A__"
#endif

#ifdef __AVR_ATmega48P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega48P__"
#endif

#ifdef __AVR_ATmega48__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega48__"
#endif

#ifdef __AVR_ATmega640__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega640__"
#endif

#ifdef __AVR_ATmega644A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega644A__"
#endif

#ifdef __AVR_ATmega644PA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega644PA__"
#endif

#ifdef __AVR_ATmega644P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega644P__"
#endif

#ifdef __AVR_ATmega644__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega644__"
#endif

#ifdef __AVR_ATmega6450A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega6450A__"
#endif

#ifdef __AVR_ATmega6450P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega6450P__"
#endif

#ifdef __AVR_ATmega6450__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega6450__"
#endif

#ifdef __AVR_ATmega645A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega645A__"
#endif

#ifdef __AVR_ATmega645P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega645P__"
#endif

#ifdef __AVR_ATmega645__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega645__"
#endif

#ifdef __AVR_ATmega6490A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega6490A__"
#endif

#ifdef __AVR_ATmega6490P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega6490P__"
#endif

#ifdef __AVR_ATmega6490__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega6490__"
#endif

#ifdef __AVR_ATmega649A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega649A__"
#endif

#ifdef __AVR_ATmega649P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega649P__"
#endif

#ifdef __AVR_ATmega649__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega649__"
#endif

#ifdef __AVR_ATmega64C1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega64C1__"
#endif

#ifdef __AVR_ATmega64HVE__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega64HVE__"
#endif

#ifdef __AVR_ATmega64M1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega64M1__"
#endif

#ifdef __AVR_ATmega64__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega64__"
#endif

#ifdef __AVR_ATmega8515__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega8515__"
#endif

#ifdef __AVR_ATmega8535__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega8535__"
#endif

#ifdef __AVR_ATmega88A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega88A__"
#endif

#ifdef __AVR_ATmega88PA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega88PA__"
#endif

#ifdef __AVR_ATmega88P__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega88P__"
#endif

#ifdef __AVR_ATmega88__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega88__"
#endif

#ifdef __AVR_ATmega8HVA__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega8HVA__"
#endif

#ifdef __AVR_ATmega8U2__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega8U2__"
#endif

#ifdef __AVR_ATmega8__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATmega8__"
#endif

#ifdef __AVR_ATtiny10__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny10__"
#endif

#ifdef __AVR_ATtiny11__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny11__"
#endif

#ifdef __AVR_ATtiny12__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny12__"
#endif

#ifdef __AVR_ATtiny13A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny13A__"
#endif

#ifdef __AVR_ATtiny13__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny13__"
#endif

#ifdef __AVR_ATtiny15__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny15__"
#endif

#ifdef __AVR_ATtiny167__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny167__"
#endif

#ifdef __AVR_ATtiny20__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny20__"
#endif

#ifdef __AVR_ATtiny22__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny22__"
#endif

#ifdef __AVR_ATtiny2313A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny2313A__"
#endif

#ifdef __AVR_ATtiny2313__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny2313__"
#endif

#ifdef __AVR_ATtiny24A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny24A__"
#endif

#ifdef __AVR_ATtiny24__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny24__"
#endif

#ifdef __AVR_ATtiny25__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny25__"
#endif

#ifdef __AVR_ATtiny261A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny261A__"
#endif

#ifdef __AVR_ATtiny261__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny261__"
#endif

#ifdef __AVR_ATtiny26__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny26__"
#endif

#ifdef __AVR_ATtiny28__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny28__"
#endif

#ifdef __AVR_ATtiny40__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny40__"
#endif

#ifdef __AVR_ATtiny4313__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny4313__"
#endif

#ifdef __AVR_ATtiny43U__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny43U__"
#endif

#ifdef __AVR_ATtiny44A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny44A__"
#endif

#ifdef __AVR_ATtiny44__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny44__"
#endif

#ifdef __AVR_ATtiny45__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny45__"
#endif

#ifdef __AVR_ATtiny461A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny461A__"
#endif

#ifdef __AVR_ATtiny461__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny461__"
#endif

#ifdef __AVR_ATtiny48__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny48__"
#endif

#ifdef __AVR_ATtiny4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny4__"
#endif

#ifdef __AVR_ATtiny5__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny5__"
#endif

#ifdef __AVR_ATtiny84A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny84A__"
#endif

#ifdef __AVR_ATtiny84__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny84__"
#endif

#ifdef __AVR_ATtiny85__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny85__"
#endif

#ifdef __AVR_ATtiny861A__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny861A__"
#endif

#ifdef __AVR_ATtiny861__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny861__"
#endif

#ifdef __AVR_ATtiny87__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny87__"
#endif

#ifdef __AVR_ATtiny88__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny88__"
#endif

#ifdef __AVR_ATtiny9__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATtiny9__"
#endif

#ifdef __AVR_ATxmega128A1U__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega128A1U__"
#endif

#ifdef __AVR_ATxmega128A1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega128A1__"
#endif

#ifdef __AVR_ATxmega128A3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega128A3__"
#endif

#ifdef __AVR_ATxmega128D3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega128D3__"
#endif

#ifdef __AVR_ATxmega16A4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega16A4__"
#endif

#ifdef __AVR_ATxmega16D4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega16D4__"
#endif

#ifdef __AVR_ATxmega192A3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega192A3__"
#endif

#ifdef __AVR_ATxmega192D3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega192D3__"
#endif

#ifdef __AVR_ATxmega256A3B__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega256A3B__"
#endif

#ifdef __AVR_ATxmega256A3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega256A3__"
#endif

#ifdef __AVR_ATxmega256D3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega256D3__"
#endif

#ifdef __AVR_ATxmega32A4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega32A4__"
#endif

#ifdef __AVR_ATxmega32D4__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega32D4__"
#endif

#ifdef __AVR_ATxmega64A1U__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega64A1U__"
#endif

#ifdef __AVR_ATxmega64A1__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega64A1__"
#endif

#ifdef __AVR_ATxmega64A3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega64A3__"
#endif

#ifdef __AVR_ATxmega64D3__
#    ifdef MCU
#        error "MCU is already defined"
#    endif
#    define MCU "__AVR_ATxmega64D3__"
#endif