
// frequently used constants should be placed first
DEFINE(A0)
DEFINE(NUM_DIGITAL_PINS)
DEFINE(RAMEND)
DEFINE(XRAMEND)
DEFINE(E2END)
DEFINE(FLASHEND)
DEFINE(SPM_PAGESIZE)
DEFINE(E2PAGESIZE)
DEFINE(F_CPU)
DEFINE(ARDUINO)
DEFINE(SS)
DEFINE(MOSI)
DEFINE(MISO)
DEFINE(SCK)
DEFINE(__AVR_LIBC_DATE_)
DEFINE(__AVR_LIBC_VERSION__)
